==> open-props-1.5.15.jar: META-INF/resources/webjars/open-props/1.5.15/src/props.sizes.d.ts <==
declare const _default: {
    '--size-000': string;
    '--size-00': string;
    '--size-1': string;
    '--size-2': string;
    '--size-3': string;
    '--size-4': string;
    '--size-5': string;
    '--size-6': string;
    '--size-7': string;
    '--size-8': string;
    '--size-9': string;
    '--size-10': string;
    '--size-11': string;
    '--size-12': string;
    '--size-13': string;
    '--size-14': string;
    '--size-15': string;
    '--size-fluid-1': string;
    '--size-fluid-2': string;
    '--size-fluid-3': string;
    '--size-fluid-4': string;
    '--size-fluid-5': string;
    '--size-fluid-6': string;
    '--size-fluid-7': string;
    '--size-fluid-8': string;
    '--size-fluid-9': string;
    '--size-fluid-10': string;
    '--size-content-1': string;
    '--size-content-2': string;
    '--size-content-3': string;
    '--size-header-1': string;
    '--size-header-2': string;
    '--size-header-3': string;
    '--size-xxs': string;
    '--size-xs': string;
    '--size-sm': string;
    '--size-md': string;
    '--size-lg': string;
    '--size-xl': string;
    '--size-xxl': string;
    '--size-relative-000': string;
    '--size-relative-00': string;
    '--size-relative-1': string;
    '--size-relative-2': string;
    '--size-relative-3': string;
    '--size-relative-4': string;
    '--size-relative-5': string;
    '--size-relative-6': string;
    '--size-relative-7': string;
    '--size-relative-8': string;
    '--size-relative-9': string;
    '--size-relative-10': string;
    '--size-relative-11': string;
    '--size-relative-12': string;
    '--size-relative-13': string;
    '--size-relative-14': string;
    '--size-relative-15': string;
};
export default _default;

==> open-props-1.7.15.jar: META-INF/resources/webjars/open-props/1.7.15/src/props.sizes.d.ts <==
declare const _default: {
    '--size-000': string;
    '--size-00': string;
    '--size-1': string;
    '--size-2': string;
    '--size-3': string;
    '--size-4': string;
    '--size-5': string;
    '--size-6': string;
    '--size-7': string;
    '--size-8': string;
    '--size-9': string;
    '--size-10': string;
    '--size-11': string;
    '--size-12': string;
    '--size-13': string;
    '--size-14': string;
    '--size-15': string;
    '--size-px-000': string;
    '--size-px-00': string;
    '--size-px-1': string;
    '--size-px-2': string;
    '--size-px-3': string;
    '--size-px-4': string;
    '--size-px-5': string;
    '--size-px-6': string;
    '--size-px-7': string;
    '--size-px-8': string;
    '--size-px-9': string;
    '--size-px-10': string;
    '--size-px-11': string;
    '--size-px-12': string;
    '--size-px-13': string;
    '--size-px-14': string;
    '--size-px-15': string;
    '--size-fluid-1': string;
    '--size-fluid-2': string;
    '--size-fluid-3': string;
    '--size-fluid-4': string;
    '--size-fluid-5': string;
    '--size-fluid-6': string;
    '--size-fluid-7': string;
    '--size-fluid-8': string;
    '--size-fluid-9': string;
    '--size-fluid-10': string;
    '--size-content-1': string;
    '--size-content-2': string;
    '--size-content-3': string;
    '--size-header-1': string;
    '--size-header-2': string;
    '--size-header-3': string;
    '--size-xxs': string;
    '--size-xs': string;
    '--size-sm': string;
    '--size-md': string;
    '--size-lg': string;
    '--size-xl': string;
    '--size-xxl': string;
    '--size-relative-000': string;
    '--size-relative-00': string;
    '--size-relative-1': string;
    '--size-relative-2': string;
    '--size-relative-3': string;
    '--size-relative-4': string;
    '--size-relative-5': string;
    '--size-relative-6': string;
    '--size-relative-7': string;
    '--size-relative-8': string;
    '--size-relative-9': string;
    '--size-relative-10': string;
    '--size-relative-11': string;
    '--size-relative-12': string;
    '--size-relative-13': string;
    '--size-relative-14': string;
    '--size-relative-15': string;
};
export default _default;
